@@ -54,7 +54,7 @@ class WitterUI():
         # set name of application: this shows in titlebar
         gtk.set_application_name("Witter")
         self.serviceName = "Witter"
-
+        self.theme = "default"
         # 
         #we want to track our position in each tweet stream so we can 
         #return to it when we switch between them
@@ -111,53 +111,53 @@ class WitterUI():
         #fix the buttons to get the style right 
         refreshButton = self.builder.get_object("Refresh")
         refImage = gtk.Image()
-        refImage.set_from_file("/opt/witter/icons/refresh.png")
+        refImage.set_from_file("/opt/witter/icons/" + self.theme + "/refresh.png")
         refImage.show()
         refreshButton.set_image(refImage)
         tweetButton = self.builder.get_object("Tweet")
         tweetImage = gtk.Image()
-        tweetImage.set_from_file("/opt/witter/icons/tweet.png")
+        tweetImage.set_from_file("/opt/witter/icons/" + self.theme + "/tweet.png")
         tweetImage.show()
         tweetButton.set_image(tweetImage)
         timelineButton = self.builder.get_object("timeline")
         tlImage = gtk.Image()
-        tlImage.set_from_file("/opt/witter/icons/timeline.png")
+        tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline.png")
         tlImage.show()
         timelineButton.set_image(tlImage)
         mentionsButton = self.builder.get_object("mentions")
         menImage = gtk.Image()
-        menImage.set_from_file("/opt/witter/icons/mention_off.png")
+        menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention_off.png")
         menImage.show()
         mentionsButton.set_image(menImage)
         dmsButton = self.builder.get_object("direct messages")
         dmImage = gtk.Image()
-        dmImage.set_from_file("/opt/witter/icons/dm_off.png")
+        dmImage.set_from_file("/opt/witter/icons/" + self.theme + "/dm_off.png")
         dmImage.show()
         dmsButton.set_image(dmImage)
         searchButton = self.builder.get_object("search")
         serImage = gtk.Image()
-        serImage.set_from_file("/opt/witter/icons/search_off.png")
+        serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search_off.png")
         serImage.show()
         searchButton.set_image(serImage)
         friendsButton = self.builder.get_object("friends")
         friendImage = gtk.Image()
-        friendImage.set_from_file("/opt/witter/icons/friends_off.png")
+        friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends_off.png")
         friendImage.show()
         friendsButton.set_image(friendImage)
         publicButton = self.builder.get_object("public")
         pubImage = gtk.Image()
-        pubImage.set_from_file("/opt/witter/icons/public_off.png")
+        pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public_off.png")
         pubImage.show()
 
         publicButton.set_image(pubImage)
         trendsButton = self.builder.get_object("trends")
         trendImage = gtk.Image()
-        trendImage.set_from_file("/opt/witter/icons/trends_off.png")
+        trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends_off.png")
         trendImage.show()
         trendsButton.set_image(trendImage)
         userButton = self.builder.get_object("userhistory")
         userImage = gtk.Image()
-        userImage.set_from_file("/opt/witter/icons/userHistory_off.png")
+        userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory_off.png")
         userImage.show()
         userButton.set_image(userImage)
 
@@ -168,7 +168,7 @@ class WitterUI():
         fullscrButton.set_image(image)
         extraButton = self.builder.get_object("extra-controls")
         image2 = gtk.Image()
-        image2.set_from_file("/opt/witter/icons/plus.png")
+        image2.set_from_file("/opt/witter/icons/" + self.theme + "/plus.png")
         image2.show()
         extraButton.set_image(image2)
 
@@ -180,22 +180,22 @@ class WitterUI():
 
 
         imageplus20 = gtk.Image()
-        imageplus20.set_from_file("/opt/witter/icons/plus20.png")
+        imageplus20.set_from_file("/opt/witter/icons/" + self.theme + "/plus20.png")
         imageplus20.show()
         plus20Button.set_image(imageplus20)
 
         imageplus50 = gtk.Image()
-        imageplus50.set_from_file("/opt/witter/icons/plus50.png")
+        imageplus50.set_from_file("/opt/witter/icons/" + self.theme + "/plus50.png")
         imageplus50.show()
         plus50Button.set_image(imageplus50)
 
         imageplus100 = gtk.Image()
-        imageplus100.set_from_file("/opt/witter/icons/plus100.png")
+        imageplus100.set_from_file("/opt/witter/icons/" + self.theme + "/plus100.png")
         imageplus100.show()
         plus100Button.set_image(imageplus100)
 
         imageplus200 = gtk.Image()
-        imageplus200.set_from_file("/opt/witter/icons/plus200.png")
+        imageplus200.set_from_file("/opt/witter/icons/" + self.theme + "/plus200.png")
         imageplus200.show()
         plus200Button.set_image(imageplus200)
 
@@ -259,7 +259,7 @@ class WitterUI():
         self.namecolour = self.textcolour
         self.tweetcolour = self.textcolour
 
-        self.defaultwidth = 790
+        self.themewidth = 790
         #default to colours above, but check if we're on fremantle and change
         #to appropriate colours if we are
 
@@ -552,7 +552,7 @@ class WitterUI():
                  self.window.unfullscreen ()
                  #when we toggle off fullscreen set the cell render wrap
                  #to 500
-                 self.cell.set_property('wrap-width', self.defaultwidth)
+                 self.cell.set_property('wrap-width', self.themewidth)
              else:
                 self.window.fullscreen ()
                 #when we toggle into fullscreen set the cell render wrap
@@ -1105,6 +1105,9 @@ class WitterUI():
         widget.reparent(newParent)
 
     def switchViewTo(self, widget, type):
+        self.switch_view_to(type)
+
+    def switch_view_to(self, type):
         if (self.getCurrentView() == self.SEARCH_VIEW):
             #switching out of search view, save search terms and reset text box
             self.controller.search_terms = self.tweetText.get_text()
@@ -1116,43 +1119,43 @@ class WitterUI():
             #ensure selected view has active button image
             timelineButton = self.builder.get_object("timeline")
             tlImage = gtk.Image()
-            tlImage.set_from_file("/opt/witter/icons/timeline.png")
+            tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline.png")
             tlImage.show()
             timelineButton.set_image(tlImage)
             #set all othe rbuttons into deactivated mode
             mentionsButton = self.builder.get_object("mentions")
             menImage = gtk.Image()
-            menImage.set_from_file("/opt/witter/icons/mention_off.png")
+            menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention_off.png")
             menImage.show()
             mentionsButton.set_image(menImage)
             searchButton = self.builder.get_object("search")
             serImage = gtk.Image()
-            serImage.set_from_file("/opt/witter/icons/search_off.png")
+            serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search_off.png")
             serImage.show()
             searchButton.set_image(serImage)
             dmsButton = self.builder.get_object("direct messages")
             dmImage = gtk.Image()
-            dmImage.set_from_file("/opt/witter/icons/dm_off.png")
+            dmImage.set_from_file("/opt/witter/icons/" + self.theme + "/dm_off.png")
             dmImage.show()
             dmsButton.set_image(dmImage)
             friendsButton = self.builder.get_object("friends")
             friendImage = gtk.Image()
-            friendImage.set_from_file("/opt/witter/icons/friends_off.png")
+            friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends_off.png")
             friendImage.show()
             friendsButton.set_image(friendImage)
             trendsButton = self.builder.get_object("trends")
             trendImage = gtk.Image()
-            trendImage.set_from_file("/opt/witter/icons/trends_off.png")
+            trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends_off.png")
             trendImage.show()
             trendsButton.set_image(trendImage)
             publicButton = self.builder.get_object("public")
             pubImage = gtk.Image()
-            pubImage.set_from_file("/opt/witter/icons/public_off.png")
+            pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public_off.png")
             pubImage.show()
             publicButton.set_image(pubImage)
             userButton = self.builder.get_object("userhistory")
             userImage = gtk.Image()
-            userImage.set_from_file("/opt/witter/icons/userHistory_off.png")
+            userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory_off.png")
             userImage.show()
             userButton.set_image(userImage)
         elif (re.search("direct", type)):
@@ -1162,43 +1165,43 @@ class WitterUI():
             self.window.set_title(self.serviceName + " - direct messages")
             dmsButton = self.builder.get_object("direct messages")
             dmImage = gtk.Image()
-            dmImage.set_from_file("/opt/witter/icons/dm.png")
+            dmImage.set_from_file("/opt/witter/icons/" + self.theme + "/dm.png")
             dmImage.show()
             dmsButton.set_image(dmImage)
             #set all othe rbuttons into deactivated mode
             timelineButton = self.builder.get_object("timeline")
             tlImage = gtk.Image()
-            tlImage.set_from_file("/opt/witter/icons/timeline_off.png")
+            tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline_off.png")
             tlImage.show()
             timelineButton.set_image(tlImage)
             mentionsButton = self.builder.get_object("mentions")
             menImage = gtk.Image()
-            menImage.set_from_file("/opt/witter/icons/mention_off.png")
+            menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention_off.png")
             menImage.show()
             mentionsButton.set_image(menImage)
             searchButton = self.builder.get_object("search")
             serImage = gtk.Image()
-            serImage.set_from_file("/opt/witter/icons/search_off.png")
+            serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search_off.png")
             serImage.show()
             searchButton.set_image(serImage)
             friendsButton = self.builder.get_object("friends")
             friendImage = gtk.Image()
-            friendImage.set_from_file("/opt/witter/icons/friends_off.png")
+            friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends_off.png")
             friendImage.show()
             friendsButton.set_image(friendImage)
             trendsButton = self.builder.get_object("trends")
             trendImage = gtk.Image()
-            trendImage.set_from_file("/opt/witter/icons/trends_off.png")
+            trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends_off.png")
             trendImage.show()
             trendsButton.set_image(trendImage)
             publicButton = self.builder.get_object("public")
             pubImage = gtk.Image()
-            pubImage.set_from_file("/opt/witter/icons/public_off.png")
+            pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public_off.png")
             pubImage.show()
             publicButton.set_image(pubImage)
             userButton = self.builder.get_object("userhistory")
             userImage = gtk.Image()
-            userImage.set_from_file("/opt/witter/icons/userHistory_off.png")
+            userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory_off.png")
             userImage.show()
             userButton.set_image(userImage)
         elif (re.search("mentions", type)):
@@ -1209,19 +1212,19 @@ class WitterUI():
             #ensure selected view has active button image
             mentionsButton = self.builder.get_object("mentions")
             menImage = gtk.Image()
-            menImage.set_from_file("/opt/witter/icons/mention.png")
+            menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention.png")
             menImage.show()
             mentionsButton.set_image(menImage)
 
             #set all othe rbuttons into deactivated mode
             timelineButton = self.builder.get_object("timeline")
             tlImage = gtk.Image()
-            tlImage.set_from_file("/opt/witter/icons/timeline_off.png")
+            tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline_off.png")
             tlImage.show()
             timelineButton.set_image(tlImage)
             searchButton = self.builder.get_object("search")
             serImage = gtk.Image()
-            serImage.set_from_file("/opt/witter/icons/search_off.png")
+            serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search_off.png")
             serImage.show()
             searchButton.set_image(serImage)
             dmsButton = self.builder.get_object("direct messages")
@@ -1231,22 +1234,22 @@ class WitterUI():
             dmsButton.set_image(dmImage)
             friendsButton = self.builder.get_object("friends")
             friendImage = gtk.Image()
-            friendImage.set_from_file("/opt/witter/icons/friends_off.png")
+            friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends_off.png")
             friendImage.show()
             friendsButton.set_image(friendImage)
             trendsButton = self.builder.get_object("trends")
             trendImage = gtk.Image()
-            trendImage.set_from_file("/opt/witter/icons/trends_off.png")
+            trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends_off.png")
             trendImage.show()
             trendsButton.set_image(trendImage)
             publicButton = self.builder.get_object("public")
             pubImage = gtk.Image()
-            pubImage.set_from_file("/opt/witter/icons/public_off.png")
+            pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public_off.png")
             pubImage.show()
             publicButton.set_image(pubImage)
             userButton = self.builder.get_object("userhistory")
             userImage = gtk.Image()
-            userImage.set_from_file("/opt/witter/icons/userHistory_off.png")
+            userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory_off.png")
             userImage.show()
             userButton.set_image(userImage)
         elif (re.search("public", type)):
@@ -1256,43 +1259,43 @@ class WitterUI():
             self.window.set_title(self.serviceName + " - public")
             publicButton = self.builder.get_object("public")
             pubImage = gtk.Image()
-            pubImage.set_from_file("/opt/witter/icons/public.png")
+            pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public.png")
             pubImage.show()
             publicButton.set_image(pubImage)
             #set all othe rbuttons into deactivated mode
             timelineButton = self.builder.get_object("timeline")
             tlImage = gtk.Image()
-            tlImage.set_from_file("/opt/witter/icons/timeline_off.png")
+            tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline_off.png")
             tlImage.show()
             timelineButton.set_image(tlImage)
             mentionsButton = self.builder.get_object("mentions")
             menImage = gtk.Image()
-            menImage.set_from_file("/opt/witter/icons/mention_off.png")
+            menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention_off.png")
             menImage.show()
             mentionsButton.set_image(menImage)
             searchButton = self.builder.get_object("search")
             serImage = gtk.Image()
-            serImage.set_from_file("/opt/witter/icons/search_off.png")
+            serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search_off.png")
             serImage.show()
             searchButton.set_image(serImage)
             dmsButton = self.builder.get_object("direct messages")
             dmImage = gtk.Image()
-            dmImage.set_from_file("/opt/witter/icons/dm_off.png")
+            dmImage.set_from_file("/opt/witter/icons/" + self.theme + "/dm_off.png")
             dmImage.show()
             dmsButton.set_image(dmImage)
             friendsButton = self.builder.get_object("friends")
             friendImage = gtk.Image()
-            friendImage.set_from_file("/opt/witter/icons/friends_off.png")
+            friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends_off.png")
             friendImage.show()
             friendsButton.set_image(friendImage)
             trendsButton = self.builder.get_object("trends")
             trendImage = gtk.Image()
-            trendImage.set_from_file("/opt/witter/icons/trends_off.png")
+            trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends_off.png")
             trendImage.show()
             trendsButton.set_image(trendImage)
             userButton = self.builder.get_object("userhistory")
             userImage = gtk.Image()
-            userImage.set_from_file("/opt/witter/icons/userHistory_off.png")
+            userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory_off.png")
             userImage.show()
             userButton.set_image(userImage)
         elif (re.search("trends", type)):
@@ -1302,43 +1305,43 @@ class WitterUI():
             self.window.set_title(self.serviceName + " - trends")
             trendsButton = self.builder.get_object("trends")
             trendImage = gtk.Image()
-            trendImage.set_from_file("/opt/witter/icons/trends.png")
+            trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends.png")
             trendImage.show()
             trendsButton.set_image(trendImage)
             #set all othe rbuttons into deactivated mode
             timelineButton = self.builder.get_object("timeline")
             tlImage = gtk.Image()
-            tlImage.set_from_file("/opt/witter/icons/timeline_off.png")
+            tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline_off.png")
             tlImage.show()
             timelineButton.set_image(tlImage)
             mentionsButton = self.builder.get_object("mentions")
             menImage = gtk.Image()
-            menImage.set_from_file("/opt/witter/icons/mention_off.png")
+            menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention_off.png")
             menImage.show()
             mentionsButton.set_image(menImage)
             searchButton = self.builder.get_object("search")
             serImage = gtk.Image()
-            serImage.set_from_file("/opt/witter/icons/search_off.png")
+            serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search_off.png")
             serImage.show()
             searchButton.set_image(serImage)
             dmsButton = self.builder.get_object("direct messages")
             dmImage = gtk.Image()
-            dmImage.set_from_file("/opt/witter/icons/dm_off.png")
+            dmImage.set_from_file("/opt/witter/icons/" + self.theme + "/dm_off.png")
             dmImage.show()
             dmsButton.set_image(dmImage)
             friendsButton = self.builder.get_object("friends")
             friendImage = gtk.Image()
-            friendImage.set_from_file("/opt/witter/icons/friends_off.png")
+            friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends_off.png")
             friendImage.show()
             friendsButton.set_image(friendImage)
             publicButton = self.builder.get_object("public")
             pubImage = gtk.Image()
-            pubImage.set_from_file("/opt/witter/icons/public_off.png")
+            pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public_off.png")
             pubImage.show()
             publicButton.set_image(pubImage)
             userButton = self.builder.get_object("userhistory")
             userImage = gtk.Image()
-            userImage.set_from_file("/opt/witter/icons/userHistory_off.png")
+            userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory_off.png")
             userImage.show()
             userButton.set_image(userImage)
         elif (re.search("friends", type)):
@@ -1348,43 +1351,43 @@ class WitterUI():
             self.window.set_title(self.serviceName + " - friends")
             friendsButton = self.builder.get_object("friends")
             friendImage = gtk.Image()
-            friendImage.set_from_file("/opt/witter/icons/friends.png")
+            friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends.png")
             friendImage.show()
             friendsButton.set_image(friendImage)
             #set all othe rbuttons into deactivated mode
             timelineButton = self.builder.get_object("timeline")
             tlImage = gtk.Image()
-            tlImage.set_from_file("/opt/witter/icons/timeline_off.png")
+            tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline_off.png")
             tlImage.show()
             timelineButton.set_image(tlImage)
             mentionsButton = self.builder.get_object("mentions")
             menImage = gtk.Image()
-            menImage.set_from_file("/opt/witter/icons/mention_off.png")
+            menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention_off.png")
             menImage.show()
             mentionsButton.set_image(menImage)
             searchButton = self.builder.get_object("search")
             serImage = gtk.Image()
-            serImage.set_from_file("/opt/witter/icons/search_off.png")
+            serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search_off.png")
             serImage.show()
             searchButton.set_image(serImage)
             dmsButton = self.builder.get_object("direct messages")
             dmImage = gtk.Image()
-            dmImage.set_from_file("/opt/witter/icons/dm_off.png")
+            dmImage.set_from_file("/opt/witter/icons/" + self.theme + "/dm_off.png")
             dmImage.show()
             dmsButton.set_image(dmImage)
             publicButton = self.builder.get_object("public")
             pubImage = gtk.Image()
-            pubImage.set_from_file("/opt/witter/icons/public_off.png")
+            pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public_off.png")
             pubImage.show()
             publicButton.set_image(pubImage)
             trendsButton = self.builder.get_object("trends")
             trendImage = gtk.Image()
-            trendImage.set_from_file("/opt/witter/icons/trends_off.png")
+            trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends_off.png")
             trendImage.show()
             trendsButton.set_image(trendImage)
             userButton = self.builder.get_object("userhistory")
             userImage = gtk.Image()
-            userImage.set_from_file("/opt/witter/icons/userHistory_off.png")
+            userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory_off.png")
             userImage.show()
             userButton.set_image(userImage)
         elif (re.search("search", type)):
@@ -1395,43 +1398,43 @@ class WitterUI():
             self.window.set_title(self.serviceName + " - search")
             searchButton = self.builder.get_object("search")
             serImage = gtk.Image()
-            serImage.set_from_file("/opt/witter/icons/search.png")
+            serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search.png")
             serImage.show()
             searchButton.set_image(serImage)
             #set all othe rbuttons into deactivated mode
             timelineButton = self.builder.get_object("timeline")
             tlImage = gtk.Image()
-            tlImage.set_from_file("/opt/witter/icons/timeline_off.png")
+            tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline_off.png")
             tlImage.show()
             timelineButton.set_image(tlImage)
             mentionsButton = self.builder.get_object("mentions")
             menImage = gtk.Image()
-            menImage.set_from_file("/opt/witter/icons/mention_off.png")
+            menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention_off.png")
             menImage.show()
             mentionsButton.set_image(menImage)
             dmsButton = self.builder.get_object("direct messages")
             dmImage = gtk.Image()
-            dmImage.set_from_file("/opt/witter/icons/dm_off.png")
+            dmImage.set_from_file("/opt/witter/icons/" + self.theme + "/dm_off.png")
             dmImage.show()
             dmsButton.set_image(dmImage)
             friendsButton = self.builder.get_object("friends")
             friendImage = gtk.Image()
-            friendImage.set_from_file("/opt/witter/icons/friends_off.png")
+            friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends_off.png")
             friendImage.show()
             friendsButton.set_image(friendImage)
             publicButton = self.builder.get_object("public")
             pubImage = gtk.Image()
-            pubImage.set_from_file("/opt/witter/icons/public_off.png")
+            pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public_off.png")
             pubImage.show()
             publicButton.set_image(pubImage)
             trendsButton = self.builder.get_object("trends")
             trendImage = gtk.Image()
-            trendImage.set_from_file("/opt/witter/icons/trends_off.png")
+            trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends_off.png")
             trendImage.show()
             trendsButton.set_image(trendImage)
             userButton = self.builder.get_object("userhistory")
             userImage = gtk.Image()
-            userImage.set_from_file("/opt/witter/icons/userHistory_off.png")
+            userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory_off.png")
             userImage.show()
             userButton.set_image(userImage)
         elif (re.search("user", type)):
@@ -1441,43 +1444,43 @@ class WitterUI():
             self.window.set_title(self.serviceName + " - User History")
             userButton = self.builder.get_object("userhistory")
             userImage = gtk.Image()
-            userImage.set_from_file("/opt/witter/icons/userHistory.png")
+            userImage.set_from_file("/opt/witter/icons/" + self.theme + "/userHistory.png")
             userImage.show()
             userButton.set_image(userImage)
             #set all othe rbuttons into deactivated mode
             searchButton = self.builder.get_object("search")
             serImage = gtk.Image()
-            serImage.set_from_file("/opt/witter/icons/search_off.png")
+            serImage.set_from_file("/opt/witter/icons/" + self.theme + "/search_off.png")
             serImage.show()
             searchButton.set_image(serImage)
             timelineButton = self.builder.get_object("timeline")
             tlImage = gtk.Image()
-            tlImage.set_from_file("/opt/witter/icons/timeline_off.png")
+            tlImage.set_from_file("/opt/witter/icons/" + self.theme + "/timeline_off.png")
             tlImage.show()
             timelineButton.set_image(tlImage)
             mentionsButton = self.builder.get_object("mentions")
             menImage = gtk.Image()
-            menImage.set_from_file("/opt/witter/icons/mention_off.png")
+            menImage.set_from_file("/opt/witter/icons/" + self.theme + "/mention_off.png")
             menImage.show()
             mentionsButton.set_image(menImage)
             dmsButton = self.builder.get_object("direct messages")
             dmImage = gtk.Image()
-            dmImage.set_from_file("/opt/witter/icons/dm_off.png")
+            dmImage.set_from_file("/opt/witter/icons/" + self.theme + "/dm_off.png")
             dmImage.show()
             dmsButton.set_image(dmImage)
             friendsButton = self.builder.get_object("friends")
             friendImage = gtk.Image()
-            friendImage.set_from_file("/opt/witter/icons/friends_off.png")
+            friendImage.set_from_file("/opt/witter/icons/" + self.theme + "/friends_off.png")
             friendImage.show()
             friendsButton.set_image(friendImage)
             publicButton = self.builder.get_object("public")
             pubImage = gtk.Image()
-            pubImage.set_from_file("/opt/witter/icons/public_off.png")
+            pubImage.set_from_file("/opt/witter/icons/" + self.theme + "/public_off.png")
             pubImage.show()
             publicButton.set_image(pubImage)
             trendsButton = self.builder.get_object("trends")
             trendImage = gtk.Image()
-            trendImage.set_from_file("/opt/witter/icons/trends_off.png")
+            trendImage.set_from_file("/opt/witter/icons/" + self.theme + "/trends_off.png")
             trendImage.show()
             trendsButton.set_image(trendImage)
 
@@ -1691,7 +1694,7 @@ class WitterUI():
        picker_button.set_selector(selector)
 
        # Attach callback to the "value-changed" signal
-       picker_button.connect("value-changed", self.on_picker_value_changed)
+       picker_button.connect("value-changed", self.select_theme, selector)
 
 
        vbox = gtk.VBox(False, 0)
@@ -1717,10 +1720,13 @@ class WitterUI():
        win.show_all()
 
     def create_theme_selector(self):
-       selector = hildon.TouchSelectorEntry(text=True)
+       selector = hildon.TouchSelector(text=True)
 
        # Stock icons will be used for the example
-       theme_list = ["Default"]
+       theme_list = []
+       for f in os.listdir("/opt/witter/icons/"):
+           if  os.path.isdir(os.path.join("/opt/witter/icons/", f)):
+                theme_list.append(f)
 
        match_found = False
        # Populate model
@@ -2146,6 +2152,27 @@ class WitterUI():
         stack.pop(1)
         self.edit_account_details(widget, account)
 
+    def select_theme(self, widget, selector):
+        self.select_ui_theme(selector.get_current_text())
 
+    def select_ui_theme(self, theme_name):
 
+        self.theme = theme_name
+        curView = self.getCurrentView()
+        if (curView == self.TIMELINE_VIEW):
+            self.switch_view_to("timeline")
+        elif (curView == self.DM_VIEW):
+            self.switch_view_to("direct")
+        elif (curView == self.MENTIONS_VIEW):
+            self.switch_view_to("mentions")
+        elif (curView == self.PUBLIC_VIEW):
+            self.switch_view_to("public")
+        elif (curView == self.TRENDS_VIEW):
+            rself.switch_view_to("trends")
+        elif (curView == self.FRIENDS_VIEW):
+            self.switch_view_to("friends")
+        elif (curView == self.SEARCH_VIEW):
+            self.switch_view_to("search")
+        elif (curView == self.USERHIST_VIEW):
+            self.switch_view_to("user")
 
